# diffindiff: Difference-in-Differences (DiD) Analysis Python Library

This Python library is designed for performing Difference-in-Differences (DiD) analyses in a convenient way. It allows users to construct datasets, define treatment and control groups, and set treatment periods. DiD model analyses may be conducted with both datasets created by built-in functions and ready-to-use external datasets. The library supports various extensions, such as two-way fixed effects models, group- or individual-specific effects, and post-treatment periods. Additionally, it includes functions for visualizing results, such as plotting DiD coefficients with confidence intervals and illustrating the temporal evolution of staggered treatments.

## Author

This library was developed by Thomas Wieland (geowieland@googlemail.com).


## Features

- **Data Setup**: Define custom treatment and control groups as well as treatment periods; Save ready-to-fit DiD objects.
- **DiD analysis**: Perfom standard DiD analysis  
**Model Extensions**: e.g.
  - Two-way fixed effects models
  - Group-specific or individual-specific effects
  - Group-specific or individual specific time trends
  - After-treatment period
  - Staggered adoption
- **Visualization**:
  - Plot observed and expected time course of treatment and control group 
  - Plot DiD coefficients with confidence intervals.
  - Visualize the temporal evolution of staggered treatments.
- **Data diagnosis**: e.g.
  - Test for control conditions
  - Test for type of adoption
  - Test whether the panel dataset is balanced 

## Examples

See the /tests directory for usage examples of most of the included functions.

## Installation

To install the package, use `pip`:

```bash
pip install diffindiff